'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const core = require('./core-99ee4b4e.js');

const TabItem = class {
    constructor(hostRef) {
        core.registerInstance(this, hostRef);
        this.isContentHidden = true;
        /**
         * This is the key of the tab.
         */
        this.value = "";
        /**
         * Label for the tab.
         */
        this.label = "";
        /**
         * If `true` a small red bubble is added to the tab.
         */
        this.bubble = false;
        /**
         * If `true` the tab is disabled.
         */
        this.disabled = false;
        /**
         * Tell's if the tab is active and the content is visible.
         */
        this.active = false;
        this.tabChanged = core.createEvent(this, "balTabChanged", 7);
    }
    activatedHandler(newActive) {
        this.isContentHidden = !newActive;
    }
    get options() {
        return {
            value: this.value,
            label: this.label,
            active: this.active,
            disabled: this.disabled,
            hasBubble: this.bubble,
        };
    }
    /**
     * Options of the tab like label, value etc.
     */
    async getOptions() {
        return this.options;
    }
    /**
     * Sets the tab active.
     */
    async setActive(active) {
        this.active = active;
    }
    componentWillLoad() {
        this.isContentHidden = !this.active;
    }
    render() {
        this.tabChanged.emit(this.options);
        return (core.h(core.Host, null, core.h("div", { style: this.isContentHidden && { display: "none" } }, core.h("slot", null))));
    }
    static get watchers() { return {
        "active": ["activatedHandler"]
    }; }
    static get style() { return ":host{display:block}"; }
};

exports.bal_tab_item = TabItem;
