'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const core = require('./core-99ee4b4e.js');

const Tabs = class {
    constructor(hostRef) {
        core.registerInstance(this, hostRef);
        this.tabsOptions = [];
        /**
         * If `true` the field expands over the whole width.
         */
        this.expanded = false;
        /**
         * If you want the rounded tab style
         */
        this.rounded = false;
        this.tabsDidChange = core.createEvent(this, "balTabsDidChange", 7);
    }
    /**
     * Dropdown a tab by the value of the tab item.
     */
    async select(value) {
        this.tabs.forEach(t => t.setActive(t.value === value));
        this.readTabItems();
    }
    componentWillLoad() {
        this.readTabItems();
    }
    tabChanged() {
        this.readTabItems();
    }
    readTabItems() {
        Promise.all(this.tabs.map(value => value.getOptions()))
            .then(tabsOptions => {
            this.tabsOptions = tabsOptions;
        });
    }
    get tabs() {
        return Array.from(this.element.querySelectorAll("bal-tab-item"));
    }
    async onSelectTab(tab) {
        if (!tab.disabled) {
            await this.select(tab.value);
            this.tabsDidChange.emit(tab);
        }
    }
    render() {
        return (core.h(core.Host, null, core.h("div", { class: [
                "tabs",
                this.rounded ? "is-rounded" : "",
                this.expanded ? "is-fullwidth" : "",
            ].join(" ") }, core.h("ul", null, this.tabsOptions.map((tab) => core.h("li", { class: [
                tab.active ? "is-active" : "",
                tab.disabled ? "is-disabled" : "",
            ].join(" ") }, core.h("a", { onClick: () => this.onSelectTab(tab) }, tab.label), core.h("span", { class: "bubble", style: !tab.hasBubble && { display: "none" } }))), core.h("li", { class: "is-right" }, core.h("slot", { name: "action" })))), core.h("slot", null)));
    }
    get element() { return core.getElement(this); }
    static get style() { return ".tabs{-webkit-touch-callout:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.tabs:not(:last-child){margin-bottom:1.5rem}*{-webkit-box-sizing:border-box;box-sizing:border-box;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;-webkit-text-size-adjust:100%;-moz-text-size-adjust:100%}.tabs{-webkit-overflow-scrolling:touch;-webkit-box-align:stretch;-ms-flex-align:stretch;align-items:stretch;font-size:.9375rem;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;overflow:hidden;overflow-x:auto;white-space:nowrap}.tabs,.tabs a{display:-webkit-box;display:-ms-flexbox;display:flex}.tabs a{-webkit-box-align:center;-ms-flex-align:center;align-items:center;border-bottom-color:#d3dbeb;border-bottom-style:solid;border-bottom-width:0;color:#222;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;margin-bottom:0;padding:.5em 1em;vertical-align:top}.tabs a:hover{border-bottom-color:transparent;color:#fff}.tabs li{display:block}.tabs li.is-active a{border-bottom-color:transparent;color:#fff}.tabs ul{-webkit-box-align:center;-ms-flex-align:center;align-items:center;border-bottom-color:#d3dbeb;border-bottom-style:solid;border-bottom-width:0;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;-ms-flex-negative:0;flex-shrink:0;-webkit-box-pack:start;-ms-flex-pack:start;justify-content:flex-start}.tabs ul.is-center,.tabs ul.is-left{padding-right:.75em}.tabs ul.is-center{-webkit-box-flex:0;-ms-flex:none;flex:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;padding-left:.75em}.tabs ul.is-right{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;padding-left:.75em}.tabs .icon:first-child{margin-right:.5em}.tabs .icon:last-child{margin-left:.5em}.tabs.is-centered ul{-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.tabs.is-right ul{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.tabs.is-boxed a{border:1px solid transparent;border-radius:4px 4px 0 0}.tabs.is-boxed a:hover{background-color:#f5f5f6;border-bottom-color:#ebecec}.tabs.is-boxed li.is-active a{background-color:#fff;border-color:#ebecec;border-bottom-color:transparent!important}.tabs.is-fullwidth li{-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;-ms-flex-negative:0;flex-shrink:0}.tabs.is-toggle a{border-color:#ebecec;border-style:solid;border-width:1px;margin-bottom:0;position:relative}.tabs.is-toggle a:hover{background-color:#f5f5f6;border-color:#e2e3e3;z-index:2}.tabs.is-toggle li+li{margin-left:-1px}.tabs.is-toggle li:first-child a{border-radius:4px 0 0 4px}.tabs.is-toggle li:last-child a{border-radius:0 4px 4px 0}.tabs.is-toggle li.is-active a{background-color:#009ee7;border-color:#009ee7;color:#039;z-index:1}.tabs.is-toggle ul{border-bottom:none}.tabs.is-toggle.is-toggle-rounded li:first-child a{border-bottom-left-radius:290486px;border-top-left-radius:290486px;padding-left:1.25em}.tabs.is-toggle.is-toggle-rounded li:last-child a{border-bottom-right-radius:290486px;border-top-right-radius:290486px;padding-right:1.25em}.tabs.is-small{font-size:.8125rem}.tabs.is-medium{font-size:1.125rem}.tabs.is-large{font-size:1.375rem}:host{display:block}.tabs{margin:0!important}.tabs>ul{margin:0;padding:0}.tabs>ul>li{position:relative}.tabs>ul>li.is-right{position:absolute;right:40px}.tabs>ul>li span.bubble{background:#f36;height:12px;width:12px;border-radius:50%;position:absolute;display:block;top:35px;right:5px}.tabs>ul>li>a{padding:32px 20px 32px 20px;line-height:1.2;cursor:pointer;color:#7188b8;font-size:1.375rem}.tabs>ul>li.is-active>a{color:#039;border-bottom:2px solid #039;padding-bottom:30px}.tabs>ul>li>a:hover{color:#039}.tabs>ul>li.is-disabled>a,.tabs>ul>li.is-disabled>a:hover{color:#7188b8;cursor:not-allowed;opacity:1%}.tabs.is-rounded{border:none}.tabs.is-rounded>ul{padding:0}.tabs.is-rounded>ul>li{padding-right:10px}.tabs.is-rounded>ul>li:last-child{padding-right:0}.tabs.is-rounded>ul>li>a{border-radius:50px;padding:7.5px 20px 9.5px 20px;line-height:1.2;cursor:pointer;color:#222;font-size:.9375rem}.tabs.is-rounded>ul>li.is-active>a,.tabs.is-rounded>ul>li>a:hover{background:#039;color:#fff;border-bottom:0}"; }
};

exports.bal_tabs = Tabs;
