import { h } from "@stencil/core";
export class Button {
    constructor() {
        /**
         * The theme type of the button. Given by bulma our css framework.
         */
        this.type = "is-primary";
    }
    render() {
        return (h("button", { class: [
                "button",
                this.type,
                this.light ? "is-light" : "",
                this.inverted ? "is-inverted" : "",
                this.outlined ? "is-outlined" : "",
                this.expanded ? "is-fullwidth" : "",
                this.loading ? "is-loading" : "",
            ].join(" "), disabled: this.disabled },
            this.loading ? (h("bal-spinner", { class: "is-small is-inverted" })) : (""),
            h("span", { style: { display: this.loading ? "none" : "inline-block" } },
                h("slot", null))));
    }
    static get is() { return "bal-button"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["button.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["button.css"]
    }; }
    static get properties() { return {
        "type": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "| \"is-primary\"\n    | \"is-info\"\n    | \"is-success\"\n    | \"is-warning\"\n    | \"is-danger\"\n    | \"is-link\"",
                "resolved": "\"is-danger\" | \"is-info\" | \"is-link\" | \"is-primary\" | \"is-success\" | \"is-warning\"",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The theme type of the button. Given by bulma our css framework."
            },
            "attribute": "type",
            "reflect": false,
            "defaultValue": "\"is-primary\""
        },
        "disabled": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "If `true` the button is disabled"
            },
            "attribute": "disabled",
            "reflect": false
        },
        "light": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "If `true` the button has a light color"
            },
            "attribute": "light",
            "reflect": false
        },
        "expanded": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "If `true` the button has a full width"
            },
            "attribute": "expanded",
            "reflect": false
        },
        "outlined": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "If `true` the button is outlined"
            },
            "attribute": "outlined",
            "reflect": false
        },
        "inverted": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "If `true` the button is inverted"
            },
            "attribute": "inverted",
            "reflect": false
        },
        "loading": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "If `true` the label is hidden and a loading spinner is shown instead."
            },
            "attribute": "loading",
            "reflect": false
        }
    }; }
}
