import { Host, h } from "@stencil/core";
export class DropdownOption {
    constructor() {
        this.hidden = false;
        /**
         * The value of the dropdown item. This value will be returned by the parent <bal-dropdown> element.
         */
        this.value = false;
        /**
         * The value of the dropdown item. This value will be returned by the parent <bal-dropdown> element.
         */
        this.label = "";
        /**
         * TODO: Describe
         */
        this.activated = false;
        /**
         * TODO: Describe
         */
        this.highlight = "";
    }
    highlightChanged() {
        this.updateLabel();
    }
    /**
     * Tell's if the item is activated by selection.
     */
    async isHidden() {
        return this.hidden;
    }
    componentDidLoad() {
        this.updateLabel();
    }
    get parent() {
        if (this.element.parentNode.tagName === "DIV") {
            // IE11 doesn't allow shadowing so we have tho navigate the dom up to the parent element.
            try {
                return this.element.parentNode.parentNode.parentNode.parentNode;
            }
            catch (e) {
                // Do nothing
            }
        }
        return this.element.parentNode;
    }
    updateLabel() {
        if (this.highlight.length > 0) {
            const index = this.label.toLowerCase().indexOf(this.highlight.toLowerCase());
            this.hidden = index < 0;
            if (index >= 0) {
                this.labelElement.innerHTML = this.label.substring(0, index)
                    + "<span class='highlight'>"
                    + this.label.substring(index, index + this.highlight.length)
                    + "</span>"
                    + this.label.substring(index + this.highlight.length, this.label.length);
            }
        }
        else {
            this.labelElement.innerHTML = this.label;
        }
    }
    async select() {
        const option = {
            label: this.label,
            value: this.value,
        };
        await this.parent.select(option);
    }
    render() {
        return (h(Host, null,
            h("button", { class: [
                    "dropdown-item",
                    this.activated ? "is-active" : "",
                    this.hidden ? "is-hidden" : "",
                ].join(" "), onClick: this.select.bind(this) },
                h("span", { ref: el => this.labelElement = el },
                    h("slot", null)))));
    }
    static get is() { return "bal-dropdown-option"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["dropdown-option.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["dropdown-option.css"]
    }; }
    static get properties() { return {
        "value": {
            "type": "any",
            "mutable": false,
            "complexType": {
                "original": "string | boolean | number | object",
                "resolved": "boolean | number | object | string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The value of the dropdown item. This value will be returned by the parent <bal-dropdown> element."
            },
            "attribute": "value",
            "reflect": false,
            "defaultValue": "false"
        },
        "label": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The value of the dropdown item. This value will be returned by the parent <bal-dropdown> element."
            },
            "attribute": "label",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "activated": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "TODO: Describe"
            },
            "attribute": "activated",
            "reflect": false,
            "defaultValue": "false"
        },
        "highlight": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "TODO: Describe"
            },
            "attribute": "highlight",
            "reflect": false,
            "defaultValue": "\"\""
        }
    }; }
    static get states() { return {
        "hidden": {}
    }; }
    static get methods() { return {
        "isHidden": {
            "complexType": {
                "signature": "() => Promise<boolean>",
                "parameters": [],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<boolean>"
            },
            "docs": {
                "text": "Tell's if the item is activated by selection.",
                "tags": []
            }
        }
    }; }
    static get elementRef() { return "element"; }
    static get watchers() { return [{
            "propName": "highlight",
            "methodName": "highlightChanged"
        }]; }
}
