import { r as registerInstance, h, H as Host, g as getElement } from './core-45f50a11.js';

const DropdownOption = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.hidden = false;
        /**
         * The value of the dropdown item. This value will be returned by the parent <bal-dropdown> element.
         */
        this.value = false;
        /**
         * The value of the dropdown item. This value will be returned by the parent <bal-dropdown> element.
         */
        this.label = "";
        /**
         * TODO: Describe
         */
        this.activated = false;
        /**
         * TODO: Describe
         */
        this.highlight = "";
    }
    highlightChanged() {
        this.updateLabel();
    }
    /**
     * Tell's if the item is activated by selection.
     */
    async isHidden() {
        return this.hidden;
    }
    componentDidLoad() {
        this.updateLabel();
    }
    get parent() {
        if (this.element.parentNode.tagName === "DIV") {
            // IE11 doesn't allow shadowing so we have tho navigate the dom up to the parent element.
            try {
                return this.element.parentNode.parentNode.parentNode.parentNode;
            }
            catch (e) {
                // Do nothing
            }
        }
        return this.element.parentNode;
    }
    updateLabel() {
        if (this.highlight.length > 0) {
            const index = this.label.toLowerCase().indexOf(this.highlight.toLowerCase());
            this.hidden = index < 0;
            if (index >= 0) {
                this.labelElement.innerHTML = this.label.substring(0, index)
                    + "<span class='highlight'>"
                    + this.label.substring(index, index + this.highlight.length)
                    + "</span>"
                    + this.label.substring(index + this.highlight.length, this.label.length);
            }
        }
        else {
            this.labelElement.innerHTML = this.label;
        }
    }
    async select() {
        const option = {
            label: this.label,
            value: this.value,
        };
        await this.parent.select(option);
    }
    render() {
        return (h(Host, null, h("button", { class: [
                "dropdown-item",
                this.activated ? "is-active" : "",
                this.hidden ? "is-hidden" : "",
            ].join(" "), onClick: this.select.bind(this) }, h("span", { ref: el => this.labelElement = el }, h("slot", null)))));
    }
    get element() { return getElement(this); }
    static get watchers() { return {
        "highlight": ["highlightChanged"]
    }; }
    static get style() { return "*{-webkit-box-sizing:border-box;box-sizing:border-box;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;-webkit-text-size-adjust:100%;-moz-text-size-adjust:100%}.dropdown{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;position:relative;vertical-align:top}.dropdown.is-active .dropdown-menu,.dropdown.is-hoverable:hover .dropdown-menu{display:block}.dropdown.is-right .dropdown-menu{left:auto;right:0}.dropdown.is-up .dropdown-menu{bottom:100%;padding-bottom:4px;padding-top:0;top:auto}.dropdown-menu{display:none;left:0;min-width:18.75rem;padding-top:4px;position:absolute;top:100%;z-index:20}.dropdown-content{background-color:#fff;border-radius:0;-webkit-box-shadow:0 0 16px 0 rgba(0,33,98,.15);box-shadow:0 0 16px 0 rgba(0,33,98,.15);padding-bottom:14px;padding-top:14px}.dropdown-item{color:#039;display:block;font-size:.875rem;line-height:1.5;padding:.375rem 1rem;position:relative}a.dropdown-item,button.dropdown-item{padding-right:3rem;text-align:left;white-space:nowrap;width:100%}a.dropdown-item.is-active,a.dropdown-item:hover,button.dropdown-item.is-active,button.dropdown-item:hover{background-color:#f0fbff;color:#039}.dropdown-divider{background-color:#99add6;border:none;display:block;height:1px;margin:.5rem 0}:host{display:block}.highlight{font-weight:700}.dropdown-item{padding:10px 17px 13px 39px;-webkit-transition:padding-left .3s ease;transition:padding-left .3s ease;border:0;background:transparent;cursor:pointer}.dropdown-item.is-hidden{display:none}.dropdown-item span{font-family:MetaPro,Arial,sans-serif}.dropdown-item:focus,.dropdown-item:hover{background:#f0fbff}.dropdown-item.is-active{font-weight:700;background:#f0fbff}.dropdown-item:focus:not(.is-active),.dropdown-item:hover:not(.is-active){padding-left:49px}"; }
};

export { DropdownOption as bal_dropdown_option };
