import { r as registerInstance, c as createEvent, h, H as Host } from './core-45f50a11.js';

const TabItem = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.isContentHidden = true;
        /**
         * This is the key of the tab.
         */
        this.value = "";
        /**
         * Label for the tab.
         */
        this.label = "";
        /**
         * If `true` a small red bubble is added to the tab.
         */
        this.bubble = false;
        /**
         * If `true` the tab is disabled.
         */
        this.disabled = false;
        /**
         * Tell's if the tab is active and the content is visible.
         */
        this.active = false;
        this.tabChanged = createEvent(this, "balTabChanged", 7);
    }
    activatedHandler(newActive) {
        this.isContentHidden = !newActive;
    }
    get options() {
        return {
            value: this.value,
            label: this.label,
            active: this.active,
            disabled: this.disabled,
            hasBubble: this.bubble,
        };
    }
    /**
     * Options of the tab like label, value etc.
     */
    async getOptions() {
        return this.options;
    }
    /**
     * Sets the tab active.
     */
    async setActive(active) {
        this.active = active;
    }
    componentWillLoad() {
        this.isContentHidden = !this.active;
    }
    render() {
        this.tabChanged.emit(this.options);
        return (h(Host, null, h("div", { style: this.isContentHidden && { display: "none" } }, h("slot", null))));
    }
    static get watchers() { return {
        "active": ["activatedHandler"]
    }; }
    static get style() { return ":host{display:block}"; }
};

export { TabItem as bal_tab_item };
