import { EventEmitter } from "../../stencil.core";
import { Option } from "../dropdown-option/dropdown-option.types";
export declare class Dropdown {
    element: HTMLElement;
    inputElement: HTMLInputElement;
    dropdownContentElement: HTMLDivElement;
    hasNoData: boolean;
    isPristine: boolean;
    activeItemIndex: number;
    selectedOption: Option;
    isActive: boolean;
    isActiveWatcher(newIsActive: boolean): Promise<void>;
    /**
     * The value of the selected dropdown item.
     */
    value: Option;
    valueWatcher(newValue: Option): void;
    componentWillLoad(): void;
    componentDidLoad(): void;
    /**
     * Instructional text that shows before the input has a value.
     */
    placeholder: string;
    /**
     * If `true`, the user cannot interact with the input.
     */
    readonly: boolean;
    /**
     * If `true`, the user cannot interact with the input.
     */
    disabled: boolean;
    disabledWatcher(newValue: boolean): void;
    /**
     * If `true`, the use can search for the option.
     */
    typeahead: boolean;
    /**
     * If `true`, the height of the dropdown content is fixed.
     */
    fixed: boolean;
    /**
     * If `true`, the component uses the whole width.
     */
    expanded: boolean;
    /**
     * Defines the trigger icon on the right site.
     */
    triggerIcon: string;
    /**
     * Emitted when the checked property has changed.
     */
    balChange: EventEmitter<Option>;
    /**
     * Emitted when the toggle loses focus.
     */
    balBlur: EventEmitter<void>;
    /**
     * Emitted when the toggle has focus..
     */
    balFocus: EventEmitter<void>;
    clickOnOutside(event: UIEvent): void;
    /**
     * Selects an option.
     */
    select(option: Option): Promise<void>;
    /**
     * Returns the value of the dropdown.
     */
    getSelected(): Promise<Option>;
    /**
     * Open & closes the dropdown.
     */
    toggle(): Promise<void>;
    /**
     * Open the dropdown menu.
     */
    open(): Promise<void>;
    /**
     * Closes the dropdown menu.
     */
    close(): Promise<void>;
    get children(): HTMLBalDropdownOptionElement[];
    get childrenWithHiddenState(): Promise<boolean[]>;
    get childrenWithActivatedState(): Promise<boolean[]>;
    get childrenWithValue(): Promise<any[]>;
    updateActivatedOptions(): void;
    clicked(): void;
    onKeyUp(event: KeyboardEvent): Promise<void>;
    handleKeyUp(event: KeyboardEvent): void;
    handleKeyDown(event: KeyboardEvent): Promise<void>;
    getNextItem(): Promise<number>;
    getPreviousItem(): Promise<number>;
    focusNextItem(isArrowDown: boolean): Promise<void>;
    render(): any;
}
